@@ -2,12 +2,12 @@
 
 ;;; Code:
 
-(autoload 'custom-add-loads "cus-load")
-
-(custom-add-loads 'speedbar '("speedbar"))
+(custom-add-loads 'dframe '("dframe"))
+(custom-add-loads 'speedbar '("sb-image" "speedbar"))
 (custom-add-loads 'tags '("speedbar"))
 (custom-add-loads 'faces '("speedbar"))
 (custom-add-loads 'speedbar-faces '("speedbar"))
+(custom-add-loads 'bigclock '("bigclock"))
 (custom-add-loads 'speedbar-vc '("speedbar"))
 
 ;;; custom-load.el ends here
